pub struct SimdAllocator { /* private fields */ }Expand description
SIMD-optimized allocator with alignment guarantees
Implementations
Sourceimpl SimdAllocator
impl SimdAllocator
Sourcepub const fn with_alignment(alignment: usize) -> Self
pub const fn with_alignment(alignment: usize) -> Self
Create a new SIMD allocator with custom alignment
Sourcepub fn stats(&self) -> &AllocatorStats
pub fn stats(&self) -> &AllocatorStats
Get allocator statistics
Sourcepub fn allocate_simd<T>(&self, count: usize) -> Option<NonNull<T>>
pub fn allocate_simd<T>(&self, count: usize) -> Option<NonNull<T>>
Allocate aligned memory for SIMD operations
Sourcepub unsafe fn deallocate_simd<T>(&self, ptr: NonNull<T>, count: usize)
pub unsafe fn deallocate_simd<T>(&self, ptr: NonNull<T>, count: usize)
Deallocate SIMD-aligned memory previously allocated by allocate_simd.
Safety
ptr must have been allocated by this allocator with count elements of type T, and
must not be used after this call.
Sourcepub fn allocate_zeroed_simd<T>(&self, count: usize) -> Option<NonNull<T>>where
T: Copy,
pub fn allocate_zeroed_simd<T>(&self, count: usize) -> Option<NonNull<T>>where
T: Copy,
Allocate zero-initialized SIMD memory
Sourcepub unsafe fn reallocate_simd<T>(
&self,
ptr: NonNull<T>,
old_count: usize,
new_count: usize,
) -> Option<NonNull<T>>
pub unsafe fn reallocate_simd<T>( &self, ptr: NonNull<T>, old_count: usize, new_count: usize, ) -> Option<NonNull<T>>
Reallocate SIMD memory with preserved alignment.
Safety
ptr must have been allocated by this allocator with old_count elements of type T.
The returned pointer (if Some) replaces ptr, which must not be used after this call.