pub struct BenchmarkSuite { /* private fields */ }Expand description
Comprehensive benchmark suite runner
Provides benchmarking capabilities for SIMD operations with cross-platform support. In no-std environments, timing functionality is limited and operations will be executed but without accurate timing measurements.
Implementations
Sourceimpl BenchmarkSuite
impl BenchmarkSuite
Sourcepub fn benchmark<F>(
&mut self,
name: &str,
iterations: u64,
operation: F,
) -> BenchmarkResultwhere
F: FnMut(),
pub fn benchmark<F>(
&mut self,
name: &str,
iterations: u64,
operation: F,
) -> BenchmarkResultwhere
F: FnMut(),
Run a benchmark and record results
In std environments, this provides accurate timing measurements. In no-std environments, the operation is executed but timing is mocked.
Sourcepub fn cross_platform_benchmark<F>(
&mut self,
operation_name: &str,
data_size: usize,
operation: F,
) -> CrossPlatformResult
pub fn cross_platform_benchmark<F>( &mut self, operation_name: &str, data_size: usize, operation: F, ) -> CrossPlatformResult
Run cross-platform comparison
Sourcepub fn get_results(&self) -> &[BenchmarkResult]
pub fn get_results(&self) -> &[BenchmarkResult]
Get all benchmark results
Sourcepub fn generate_report(&self) -> BenchmarkReport
pub fn generate_report(&self) -> BenchmarkReport
Generate performance report