macro_rules! select_target_impl {
($generic:expr, $avx2:expr, $avx512:expr) => { ... };
}Expand description
Select implementation at compile time based on target features
macro_rules! select_target_impl {
($generic:expr, $avx2:expr, $avx512:expr) => { ... };
}Select implementation at compile time based on target features