SafeSimdOps

Struct SafeSimdOps 

pub struct SafeSimdOps;
Safe SIMD vector operations with comprehensive bounds checking

Implementations

Source

impl SafeSimdOps

pub fn validate_f32(value: f32) -> SafeSimdResult<f32>

Safely validate floating point values

pub fn validate_f64(value: f64) -> SafeSimdResult<f64>

Safely validate floating point values

pub fn validate_f32_slice(values: &[f32]) -> SafeSimdResult<()>

Validate an entire slice of f32 values

pub fn validate_f64_slice(values: &[f64]) -> SafeSimdResult<()>

Validate an entire slice of f64 values

pub fn safe_add_f32(a: f32, b: f32) -> SafeSimdResult<f32>

Safe addition with overflow detection

pub fn safe_sub_f32(a: f32, b: f32) -> SafeSimdResult<f32>

Safe subtraction with overflow detection

pub fn safe_mul_f32(a: f32, b: f32) -> SafeSimdResult<f32>

Safe multiplication with overflow detection

pub fn safe_div_f32(a: f32, b: f32) -> SafeSimdResult<f32>

Safe division with zero and overflow checking

pub fn safe_sqrt_f32(value: f32) -> SafeSimdResult<f32>

Safe square root with negative number checking

pub fn safe_ln_f32(value: f32) -> SafeSimdResult<f32>

Safe logarithm with domain checking

pub fn safe_exp_f32(value: f32) -> SafeSimdResult<f32>

Safe exponential with overflow checking

pub fn safe_dot_product_f32(a: &[f32], b: &[f32]) -> SafeSimdResult<f32>

Safe vector dot product with bounds checking

pub fn safe_normalize_f32(vector: &[f32]) -> SafeSimdResult<Vec<f32>>

Safe vector normalization

pub fn safe_get<T>(slice: &[T], index: usize) -> SafeSimdResult<&T>

Safe array indexing with bounds checking

pub fn safe_get_mut<T>(slice: &mut [T], index: usize) -> SafeSimdResult<&mut T>

Safe mutable array indexing with bounds checking

pub fn safe_slice<T>( slice: &[T], start: usize, end: usize, ) -> SafeSimdResult<&[T]>

Safe slice creation with bounds checking

pub fn all_finite_f32(values: &[f32]) -> bool

Check if all values in slice are finite (not NaN or infinite)

pub fn all_finite_f64(values: &[f64]) -> bool

Check if all values in slice are finite (not NaN or infinite)

pub fn sanitize_f32_slice( values: &mut [f32], nan_replacement: f32, inf_replacement: f32, )

Replace NaN and infinite values with safe alternatives

pub fn sanitize_f64_slice( values: &mut [f64], nan_replacement: f64, inf_replacement: f64, )

Replace NaN and infinite values with safe alternatives